# $NetBSD: doc.docbook.dsssl.mk,v 1.11 2005/10/13 09:24:33 rillig Exp $

# This file is included by doc.docbook.mk and is not intended to be
# included directly.

JADE_BIN?=	openjade
JADE?=		env ${JADE_ENV} ${JADE_BIN} 
JADETEX_BIN?=	jadetex
JADETEX?=	${JADETEX_BIN}
JADE_ENV?=	SP_ENCODING=${SP_ENCODING} \
		SGML_CATALOG_FILES= 

JADE_OPTS= -d ${DSSSL} ${SGML_CATALOGS} -i sgml.includes ${JADE_FLAGS}

DSSSL?=	${.CURDIR}/share/default.dsl

# DocBook DSSSL params for each formats .......................................

.if !defined(DSL_COMMON_PARAMS) || empty(DSL_COMMON_PARAMS)
DSL_COMMON_PARAMS+=	DSL_GENERATE_ARTICLE_TOC
.endif

.if !defined(DSL_HTML_SINGLE_PARAMS) || empty(DSL_HTML_SINGLE_PARAMS)
DSL_HTML_SINGLE_PARAMS+= ${DSL_COMMON_PARAMS}
DSL_HTML_SINGLE_PARAMS+= DSL_DBX_WITH_OUTPUT_HTML
DSL_HTML_SINGLE_PARAMS+= DSL_DBX_WITH_NOCHUNKS
.endif

.if !defined(DSL_HTML_SPLIT_PARAMS) || empty(DSL_HTML_SPLIT_PARAMS)
DSL_HTML_SPLIT_PARAMS+= ${DSL_COMMON_PARAMS}
DSL_HTML_SPLIT_PARAMS+= DSL_DBX_WITH_OUTPUT_HTML
DSL_HTML_SPLIT_PARAMS+= DSL_DBX_WITH_MANIFEST
.endif

.if !defined(DSL_TEX_PARAMS) || empty(DSL_TEX_PARAMS)
DSL_TEX_PARAMS+= ${DSL_COMMON_PARAMS}
DSL_TEX_PARAMS+= DSL_DBX_WITH_OUTPUT_TEX
DSL_TEX_PARAMS+= DSL_DBX_WITH_OUTPUT_NICEHEADERS
.endif

.if !defined(DSL_RTF_PARAMS) || empty(DSL_RTF_PARAMS)
DSL_RTF_PARAMS+= ${DSL_COMMON_PARAMS}
DSL_RTF_PARAMS+= DSL_DBX_WITH_OUTPUT_RTF
.endif

# translate params to Jade's options

.for P in DSL_HTML_SINGLE_PARAMS DSL_HTML_SPLIT_PARAMS DSL_TEX_PARAMS
.for V in ${$P}
_T:=${V}
.if ${_T} == DSL_DBX_WITH_NOCHUNKS
${P:S/PARAMS/OPTS/}+= -V nochunks
.elif ${_T} == DSL_GENERATE_ARTICLE_TOC
${P:S/PARAMS/OPTS/}+= -V %generate-article-toc%
.elif ${_T} == DSL_DBX_WITH_OUTPUT_HTML
${P:S/PARAMS/OPTS/}+= -t sgml -i output.html
.elif ${_T} == DSL_DBX_WITH_MANIFEST
${P:S/PARAMS/OPTS/}+= -V html-manifest
.elif ${_T} == DSL_DBX_WITH_OUTPUT_TEX
${P:S/PARAMS/OPTS/}+= -t tex  -i output.print -i output.print.tex
.elif ${_T} == DSL_DBX_WITH_OUTPUT_NICEHEADERS
${P:S/PARAMS/OPTS/}+= -i output.print.niceheaders
.elif ${_T} == DSL_DBX_WITH_OUTPUT_RTF
${P:S/PARAMS/OPTS/}+= -t rtf  -i output.print -i output.print.rtf
.endif
.endfor
.endfor

# targets .....................................................................

.if ${FORMATS:Mhtml} == html || ${FORMATS:Mascii} == ascii
CLEANFILES+=	${DOC}.html
.endif
.if ${FORMATS:Mhtml-split} == html-split
CLEANFILES+=	${HTML_INDEX}
.endif
.if ${FORMATS:Mps} == ps || ${FORMATS:Mpdf} == pdf
CLEANFILES+=	${DOC}.tex
CLEANFILES+=	${DOC}.aux
CLEANFILES+=	${DOC}.dvi
CLEANFILES+=	${DOC}.log
CLEANFILES+=	${DOC}.out
.endif
.if ${FORMATS:Mps} == ps
CLEANFILES+=	${DOC}.ps
.endif
.if ${FORMATS:Mpdf} == pdf
CLEANFILES+=	${DOC}.pdf
.endif
.if ${FORMATS:Mascii} == ascii
CLEANFILES+=	${DOC}.txt
.endif

${HTML_INDEX}: ${DOC}.xml
	${JADE} ${JADE_OPTS} ${DSL_HTML_SPLIT_OPTS} $(XML_DECL) $?
.if !defined(NO_TIDY)
	-${TIDY} `cat ${MANIFEST}` 
.endif

${DOC}.html: ${DOC}.xml
	${JADE} ${JADE_OPTS} ${DSL_HTML_SINGLE_OPTS} $(XML_DECL) $? > $@
.if !defined(NO_TIDY)
	-${TIDY} $@
.endif

.xml.tex:
	${JADE} ${JADE_OPTS} ${DSL_TEX_OPTS} -o $@ $(XML_DECL) $<

.tex.ps:
	-$(JADETEX) $*.tex
	-$(JADETEX) $*.tex
	-$(JADETEX) $*.tex
	${DVIPS} -f $*.dvi > $@
	rm -f *.log *.aux

.ps.pdf:
	$(PS2PDF) $<

# w3m doesn't render &#8220 or &#8221 properly, so just replace them
# with normal double quotes.
${DOC}.txt: ${DOC}.html
	${SED} -e 's/&#822[01];/"/g' $? > ${DOC}.tmp.html
	${W3M} ${DOC}.tmp.html | ${SED} -e 's/[^[:print:]]/ /g' > $@
